.. pk.py documentation master file, created by
   sphinx-quickstart on Sat Jun 12 15:44:22 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. currentmodule:: pluralkit

Welcome to pluralkit.py's documentation!
========================================

**pluralkit.py** is a Python wrapper for `PluralKit's API`_ created with `discord.py`_ in mind.

If visiting here for the first time, check out :ref:`the Getting Started page <getting_started>`!

.. _`PluralKit's API`: https://pluralkit.me/
.. _`discord.py`: https://discordpy.readthedocs.io/en/stable/

Contents
--------

.. toctree::
   :maxdepth: 3

   source/api
   source/quickstart
   source/changelog

Links
-----

- `PyPI link`_
- `pluralkit.py's Discord support server`_
- `PluralKit's API`_
- `PluralKit support server`_

.. _`PyPI link`: https://pypi.org/project/pluralkit/
.. _`pluralkit.py's Discord support server`: https://discord.gg/secvguatbC
.. _`PluralKit's API`: https://pluralkit.me/
.. _`PluralKit support server`: https://discord.gg/PczBt78

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
